-- widget title=Migration overview, row=0, col=0, size_x=8, size_y=3

# Migration overview

[Quick link to the table upgrade documentation](https://github.com/databrickslabs/ucx/blob/main/docs/table_upgrade.md)
